==> normcap-0.5.8.tar.gz: normcap-0.5.8/docs/contribute.md <==
---
hide:
  - navigation
---

# Contribute

<p class="md-subtitle">You want to support NormCap? There are many ways!</p>

## Everybody

- Tell your friends about NormCap.
- Provide [feedback](https://github.com/dynobo/normcap/discussions/categories/feedback) and [ideas](https://github.com/dynobo/normcap/discussions/categories/ideas).
- [Buy me a coffee.](https://www.buymeacoffee.com/dynobo)

## Native English speakers

- Proofread this documentation
- Proofread the English [locale](https://github.com/dynobo/normcap/tree/main/normcap/resources/locales) of NormCap

## Native speakers of other languages

- Help to [translate NormCap's UI](https://github.com/dynobo/normcap/tree/main/normcap/resources/locales)

## Designers & UX

- Suggest improvements of UX
- Improve visuals used in NormCap, like [images](https://github.com/dynobo/normcap/tree/main/normcap/resources/images) or [icons](https://github.com/dynobo/normcap/tree/main/normcap/resources/icons)
- Improve [other visuals](https://github.com/dynobo/normcap/tree/main/assets) or create a better [intro screencast](https://github.com/dynobo/normcap/tree/main/assets/screencast)

## Python Developers

- Support with [open issues](https://github.com/dynobo/normcap/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22)
- PySide / PyQT expert? Please [reach out](https://github.com/dynobo/normcap/issues/602), I'm desperately searching for someone experienced to refactor the GUI modules!
- Help with support:
    - [Triage of issues](https://github.com/dynobo/normcap/issues?q=is%3Aissue+label%3Atriage+), by reproducing bugs or asking for missing information, or even fixing the bug?
- Help with maintenance tasks:
    - Bumping versions of [dependencies](https://github.com/dynobo/normcap/blob/main/pyproject.toml) or [GitHub actions](https://github.com/dynobo/normcap/blob/main/.github/workflows/cicd.yaml)
    - Help to improve [test coverage](https://coveralls.io/github/dynobo/normcap)

!!! warning
    When in doubt, please share your contribution ideas _before_ you start working on it to avoid any unnecessary disappointment.

==> normcap-0.6.0b1.tar.gz: normcap-0.6.0b1/docs/contribute.md <==
---
hide:
  - navigation
---

# Contribute

<p class="md-subtitle">You want to support NormCap? There are many ways!</p>

## Everybody

- Tell your friends about NormCap.
- Provide [feedback](https://github.com/dynobo/normcap/discussions/categories/feedback) and [ideas](https://github.com/dynobo/normcap/discussions/categories/ideas).
- [Buy me a coffee.](https://www.buymeacoffee.com/dynobo)

## Native English speakers

- Proofread this documentation
- Proofread the English [locale](https://github.com/dynobo/normcap/tree/main/normcap/resources/locales) of NormCap

## Native speakers of other languages

- Help to [translate NormCap's UI via Weblate](https://hosted.weblate.org/projects/normcap/ui/)

## Designers & UX

- Suggest improvements of UX
- Improve visuals used in NormCap, like [images](https://github.com/dynobo/normcap/tree/main/normcap/resources/images) or [icons](https://github.com/dynobo/normcap/tree/main/normcap/resources/icons)
- Improve [other visuals](https://github.com/dynobo/normcap/tree/main/assets) or create a better [intro screencast](https://github.com/dynobo/normcap/tree/main/assets/screencast)

## Python Developers

- Support with [open issues](https://github.com/dynobo/normcap/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22)
- PySide / PyQT expert? Please [reach out](https://github.com/dynobo/normcap/issues/602), I'm desperately searching for someone experienced to refactor the GUI modules!
- Help with support:
    - [Triage of issues](https://github.com/dynobo/normcap/issues?q=is%3Aissue+label%3Atriage+), by reproducing bugs or asking for missing information, or even fixing the bug?
- Help with maintenance tasks:
    - Bumping versions of [dependencies](https://github.com/dynobo/normcap/blob/main/pyproject.toml) or [GitHub actions](https://github.com/dynobo/normcap/blob/main/.github/workflows/cicd.yaml)
    - Help to improve [test coverage](https://coveralls.io/github/dynobo/normcap)

!!! warning
    When in doubt, please share your contribution ideas _before_ you start working on it to avoid any unnecessary disappointment.
